import ts from 'typescript';
import { TypeDeclaration } from './utils';
import * as typescriptGenerator from './typescript-generator';
export declare class Generator {
    sourceFiles: ts.SourceFile[];
    private looseMode;
    declarations: TypeDeclaration[];
    constructor(sourceFiles: ts.SourceFile[], looseMode: boolean, disableWarning: boolean | undefined, getRelativePath: (fileName: string) => string, checker?: ts.TypeChecker);
    generateProtobuf(): string;
    generateJsonSchemas(): {
        entry: string;
        schema: {
            $ref: string;
            definitions: {
                [name: string]: import("./json-schema-generator").Definition;
            };
        };
    }[];
    generateSwaggerDoc(swaggerBase?: Record<string, unknown>): string;
    generateTypescript(): string;
    generateMarkdownDoc(): string;
}
export * from './utils';
export * from './typescript-generator';
export * from './json-schema-generator';
export * from './swagger-doc-generator';
export interface Configuration {
    files: string[];
    jsonSchemaOutputDirectory?: string;
    protobufOutputPath?: string;
    swagger?: {
        outputPath: string;
        base?: string | Record<string, unknown>;
    };
    typescriptOutputPath?: string;
    debugOutputPath?: string;
    watch?: boolean;
    loose?: boolean;
    plugins?: (string | ConfigInterface)[];
    markdownOutputPath?: string;
    /**
     * @deprecated
     */
    customPath?: string;
}
export declare type ConfigInterface = (typeDeclarations: TypeDeclaration[], modules: typeof typescriptGenerator) => string | {
    path: string;
    content: string;
}[];
