"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Generator = void 0;
const tslib_1 = require("tslib");
const parser_1 = require("./parser");
const protobuf_generator_1 = require("./protobuf-generator");
const json_schema_generator_1 = require("./json-schema-generator");
const swagger_doc_generator_1 = require("./swagger-doc-generator");
const typescriptGenerator = (0, tslib_1.__importStar)(require("./typescript-generator"));
const markdown_doc_generator_1 = require("./markdown-doc-generator");
class Generator {
    sourceFiles;
    looseMode;
    declarations = [];
    constructor(sourceFiles, looseMode, disableWarning = false, getRelativePath, checker) {
        this.sourceFiles = sourceFiles;
        this.looseMode = looseMode;
        const parser = new parser_1.Parser(sourceFiles, getRelativePath, checker);
        parser.disableWarning = disableWarning;
        this.declarations = parser.parse();
    }
    generateProtobuf() {
        return (0, protobuf_generator_1.generateProtobuf)(this.declarations);
    }
    generateJsonSchemas() {
        return (0, json_schema_generator_1.generateJsonSchemas)({
            declarations: this.declarations,
            looseMode: this.looseMode
        });
    }
    generateSwaggerDoc(swaggerBase) {
        return (0, swagger_doc_generator_1.generateSwaggerDoc)({
            declarations: this.declarations,
            allowFileType: true,
            looseMode: this.looseMode
        }, swaggerBase);
    }
    generateTypescript() {
        return typescriptGenerator.generateTypescript(this.declarations);
    }
    generateMarkdownDoc() {
        return (0, markdown_doc_generator_1.generateMarkdownDoc)(this.declarations);
    }
}
exports.Generator = Generator;
(0, tslib_1.__exportStar)(require("./utils"), exports);
(0, tslib_1.__exportStar)(require("./typescript-generator"), exports);
(0, tslib_1.__exportStar)(require("./json-schema-generator"), exports);
(0, tslib_1.__exportStar)(require("./swagger-doc-generator"), exports);
