"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getJsDocs = void 0;
function getJsDocs(node) {
    const jsDocs = node.jsDoc;
    const result = [];
    if (jsDocs && jsDocs.length > 0) {
        for (const jsDoc of jsDocs) {
            if (jsDoc.tags) {
                for (const tag of jsDoc.tags) {
                    result.push(getJsDocFromTag(tag));
                }
            }
            else if (typeof jsDoc.comment === 'string') {
                result.push({
                    name: '',
                    comment: jsDoc.comment,
                });
            }
            else if (jsDoc.comment) {
                for (const comment of jsDoc.comment) {
                    result.push({
                        name: '',
                        comment: comment.text,
                    });
                }
            }
        }
    }
    return result;
}
exports.getJsDocs = getJsDocs;
function getJsDocFromTag(tag) {
    let type;
    let paramName;
    let optional;
    if (tag.tagName.text === 'param') {
        const typeExpression = tag.typeExpression;
        if (typeExpression) {
            type = typeExpression.type;
            paramName = tag.name.text;
            optional = tag.isBracketed;
        }
    }
    return {
        name: tag.tagName.text,
        type,
        paramName,
        comment: typeof tag.comment === 'string' ? tag.comment : undefined,
        optional
    };
}
